<?php
/**
 * @file
 * Manage organic groups users and select groups for a given user on site
 * Menu callbacks in the site admin area
 * (c) Ilya V. Azarov, 2011.
 */
function _og_manage_admin_user_list() {
  drupal_add_css(drupal_get_path('module', 'og_manage') . '/og_manage.css');
  drupal_set_message('This module is under construction now. All this code is in progress. But you can use tabs on user account. They works properly', 'warning');
  drupal_set_title('Users and their organic groups');
  $out = drupal_get_form('_og_manage_admin_user_filter_form');
  $session = &$_SESSION['og_manage_admin_user_filter'];
  // detect node types of og
  $types = node_get_types();
  $tlist = array();
  foreach ($types as $type) {
    if (og_is_group_type($type->type) ) {
      $tlist []= '\'' . db_escape_string($type->type) . '\'';
    }
  }
  $_in = implode(', ', $tlist);
  $n = NULL;
  if ($session) {
    $result = db_query('SELECT nid, title FROM {node} WHERE title=\'%s\' AND type IN (' . $_in . ') LIMIT 1', $session);
    if ($n = db_fetch_object($result) ) {
    } else {
      $out .= '<div class="clear-block og-manage-nonode">' . t('No group with such name. Try use another filter settings.')  . '</div>';
      return $out;
    }
  }
  if ($n) {
    $sql = 'SELECT u.uid, u.name, u.status, u.created, u.access FROM {og_uid} o INNER JOIN {users} u ON o.uid=u.uid WHERE o.nid=\'' 
      . db_escape_string($n->nid) . '\' ORDER BY u.name';
    $query_count = 'SELECT count(o.uid) FROM {og_uid} o WHERE  WHERE o.nid=\'' . db_escape_string($n->nid) . '\'';
  } 
  else {
    $sql = 'SELECT u.uid, u.name, u.status, u.created, u.access FROM {users} u WHERE u.uid != 0 ORDER BY u.name';
    $query_count = 'SELECT COUNT(u.uid) FROM {users} u WHERE u.uid != 0';
  }
  $result = pager_query($sql, 50, 0, $query_count);
  $users = array();
  while ($row = db_fetch_object($result) ) {
    if ($u = user_load($row->uid) ) {
      $users []= $u;
    }
  }
  if (count($users) ) {
    $status = array(t('blocked'), t('active') );
    $header = array(
      array('data' => t('Username'),),
      array('data' => t('Status'),),
      array('data' => t('Organic groups'),),
      array('data' => t('Member for'),),
      array('data' => t('Last access'),),
      t('Operations'),
    );
    $og = array();
    $rows = array();
    foreach ($users as $u) {
      // calculate groups
      $groups = array();
      if (is_array($u->og_groups) && count($u->og_groups) ) {
        foreach ($u->og_groups as $group) {
          $group = (array) $group;
          $groups[] = l($group['title'], 'node/' . $group['nid'] );
        }
      }
      if (count($groups) ) {
        $groups = theme('item_list', $groups);
      }
      else {
        $groups = '';
      }
      $rows []= array(
        array('data' => l($u->name, 'user/' . $u->uid) ),
        array('data' => $status[$u->status] ),
        array('data' => $groups),
        array('data' => format_interval(time() - $u->created) ),
        array('data' => $u->access ? t('@time ago', array('@time' => format_interval(time() - $u->access))) : t('never') ),
        array('data' => l('View', 'user/' . $u->uid) ),
      );
    }
    $out .= theme('table',  $header, $rows, array('id' => 'og_manage_groups') );
    $out .= theme('pager');
  }
  else {
    $out .= '<div class="clear-block og-manage-nonode">' . t('No users were found by your filter.')  . '</div>';
  }
  return $out;
}
function _og_manage_admin_user_filter_form(&$form_state) {
  if (!isset($_SESSION['og_manage_admin_user_filter'] ) ) {
    $_SESSION['og_manage_admin_user_filter'] =  '';
  }
  $session = &$_SESSION['og_manage_admin_user_filter'];
  if (!is_scalar($session) ) {
    $session = '';
  }
  $form = array();
  $form['filters'] = array(
    '#type' => 'fieldset',
    '#title' => t('Show only users from this group'),
    '#theme' => 'og_manage_admin_user_filter',
    'group_name' => array(
      '#type' => 'textfield',
      //'#title' => t('Group title'),
      //'#description' => t('Enter title of group you need filter by'),
      '#default_value' => $session,
      '#autocomplete_path' => 'admin/user/og_manage/group_autocomplete',
    ),
    'buttons' => array(
      'set_filter' => array(
        '#type' => 'submit',
        '#value' => t('Set filter'),
      ),
    ),
  );
  if(!empty($session) ) {
    $form['filters']['buttons'] ['drop_filter'] = array(
      '#type' => 'submit',
      '#value' => t('Drop filter'),
    );
  }
  return $form;
}

function _og_manage_admin_user_filter_form_submit($form, &$form_state) {
  if (!isset($_SESSION['og_manage_admin_user_filter'] ) ) {
    $_SESSION['og_manage_admin_user_filter'] =  '';
  }
  $session = &$_SESSION['og_manage_admin_user_filter'];
  if (!is_scalar($session) ) {
    $session = '';
  }
  if ($form_state['values']['op'] == t('Drop filter') )  {
    $session = '';
  } elseif ($form_state['values']['op'] == t('Set filter') ) {
    $session = $form_state['values']['group_name'];
  }
}

function _og_manage_admin_og_autocomplete() {
  $args = func_get_args();
  $ret = array();
  if (count($args) ) {
    $str = implode('/', $args);
    if (strlen($str) >= 1) {
      // detect node types of og
      $types = node_get_types();
      $tlist = array();
      foreach ($types as $type) {
        if (og_is_group_type($type->type) ) {
          $tlist []= $type->type;
        }
      }
      if (count($tlist) ) {
        // may be we do not need that for security but....
        foreach ($tlist as $key => $type) {
          // to make possible put in query
          $tlist[$key] = '\''. db_escape_string($type) . '\'';
        }
        $_in = implode(', ', $tlist);
        // like escape for str
        $str = str_replace(array('%', '_', '='), array('=%', '=_', '=='), $str) . '%';
        $result = db_query(
          'SELECT nid, title, created FROM {node} WHERE title LIKE \'%s\' ESCAPE \'=\' AND type IN (' . $_in 
            . ') AND status=1 ORDER BY title LIMIT 10',
          $str
        );
        while ($row = db_fetch_array($result) ) {
          $ret[$row['title'] ] = $row['title'];
        }
      }
    }
  }
  drupal_json($ret);
  die();
}
function theme_og_manage_admin_user_filter($form) {
  $output = '<dl class="multiselect">';
  foreach (element_children($form) as $key) {
    $output .= '<dt>' . drupal_render($form[$key]) . '</dt>';
  }
  $output .= '<dd>';
  foreach (element_children($form['buttons'] ) as $key) {
    $output .= drupal_render($form[$key]);
  }
  $output .= '</dd></dl>';
  return $output;
}
