<?php
/**
 * @file
 * Manage organic groups users and select groups for a given user on site
 * Menu callbacks to select groups for single user
 * (c) Ilya V. Azarov, 2011.
 */
function _og_manage_user($account) {
  global $user;
  $out = '';
  drupal_set_title(t('Groups of user @u', array('@u' => $account->name) ) );
  $types = node_get_types();
  $tlist = array();
  foreach ($types as $type) {
    if (og_is_group_type($type->type) ) {
      $tlist []= $type;
    }
  }
  if (count($tlist) ) {
    $grouplist = array();
    foreach ($tlist as $type) {
      $result = db_query('SELECT nid, title, created FROM {node} WHERE type=\'%s\' ORDER BY title', $type->type);
      while ($row = db_fetch_array($result) ) {
        $grouplist[$type->type] [$row['nid'] ] = $row;
      }
    }
    if (count($grouplist) ) {
      // check if user is member of groups here
      $out .= drupal_get_form('_og_manage_user_form', $account, $tlist, $grouplist);
    }
    else {
      $out .= '<div class="go-manage-user-no-groups">'
        . t('OG node types are defined in your system, but there no such content. You\'ve not created any groups yet')
        . '</div>';
    }
  }
  else {
    $out .= '<div class="go-manage-user-no-groups">'
      . t('Sorry, even open groups types are not defined on your site. Please configure some types as OG nodes and create groups you need')
      . '</div>';
  }
  return $out;
}
function _og_manage_user_form(&$form_state, $account, $types, $grouplist) {
  $form = array();
  $form['uid'] = array(
    '#type' => 'hidden',
    '#default_value' => $account->uid,
    '#value' => $account->uid,
  );
  foreach ($types as $type) {
    $form[$type->type] = array(
      '#type' => 'fieldset',
      '#title' => theme('og_manage_grouptype_description', $type),
      '#tree' => TRUE,
    );
    foreach ($grouplist[$type->type] as $group) {
      $form[$type->type][$group['nid'] ] = array(
        '#type' => 'checkbox',
        '#title' => l(
          $group['title'], 
          'node/' . $group['nid'], 
          array('attributes' => array('class' => 'user-og_manage-group-link') )
        ),
        '#default_value' => og_is_group_member($group['nid'], TRUE, $account->uid),
      );
    }
  }
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save groups membership for this user'),
  );
  drupal_add_js('
$(document).ready(function() {
  $("a.user-og_manage-group-link").click(function(){
      window.open($(this).attr("href"), "_blank");
      return false;
    }
  );
});', 'inline', 'footer');
  return $form;
}
function _og_manage_user_form_submit($form, &$form_state) {
  $uid = intval($form_state['values']['uid'] );
  $account = user_load(array('uid' => $uid) );
  $types = node_get_types();
  $tlist = array();
  foreach ($types as $type) {
    if (og_is_group_type($type->type) ) {
      $tlist []= $type;
    }
  }
  if (count($tlist) ) {
    $grouplist = array();
    foreach ($tlist as $type) {
      $result = db_query('SELECT nid, title, created FROM {node} WHERE type=\'%s\' ORDER BY title', $type->type);
      while ($row = db_fetch_array($result) ) {
        $grouplist[$type->type] [$row['nid'] ] = $row;
      }
    }
    if (count($grouplist) ) {
      foreach ($tlist as $type) {
        foreach ($grouplist[$type->type] as $group) {
          if ($form_state['values'] [$type->type] [$group['nid'] ] ) {
            og_save_subscription($group['nid'], $uid, array('is_active' => 1) );
          } else {
            og_save_subscription($group['nid'], $uid, array('is_active' => 0) );
          }
        }
      }
    }
  }
  drupal_set_message(t('Groups for this user were saved') );
}
function theme_og_manage_grouptype_description($type) {
  return t('Groups of type "%type"', array('%type' => $type->name) );
}
